@@ -69,15 +69,15 @@ class FocalLoss(nn.Module):
 
 
 class NegativeCElLoss(nn.Module):
-    def __init__(self, ratio=0.7):
+    def __init__(self):
         super(NegativeCElLoss, self).__init__()
-        self.ratio = ratio
         self.softmax = nn.Softmax()
         self.nll = nn.NLLLoss(ignore_index=-1)
 
     def forward(self, input, target):
         nsoftmax = self.softmax(input)
-        nsoftmax = torch.clamp((1.0 - nsoftmax), min=1e-5)
+        nsoftmax = torch.clamp((1.0 - nsoftmax), min=1e-32)
+        # nsoftmax = 1.0 - nsoftmax
         return self.nll(torch.log(nsoftmax), target)
 
 
